/* http://meyerweb.com/eric/tools/css/reset/
   v2.0 | 20110126
   License: none (public domain)
*/
/* index.css */
html,
body,
div,
span,
applet,
object,
iframe,
h1,
h2,
h3,
h4,
h5,
h6,
p,
blockquote,
pre,
a,
abbr,
acronym,
address,
big,
cite,
code,
del,
dfn,
em,
img,
ins,
kbd,
q,
s,
samp,
small,
strike,
strong,
sub,
sup,
tt,
var,
b,
u,
i,
center,
dl,
dt,
dd,
ol,
ul,
li,
fieldset,
form,
label,
legend,
table,
caption,
tbody,
tfoot,
thead,
tr,
th,
td,
article,
aside,
canvas,
details,
embed,
figure,
figcaption,
footer,
header,
hgroup,
menu,
nav,
output,
ruby,
section,
summary,
time,
mark,
audio,
video {
  margin: 0;
  padding: 0;
  border: 0;
  font-size: 100%;
  font: inherit;
  vertical-align: baseline;
}
/* HTML5 display-role reset for older browsers */
article,
aside,
details,
figcaption,
figure,
footer,
header,
hgroup,
menu,
nav,
section {
  display: block;
}
body {
  line-height: 1;
}
ol,
ul {
  list-style: none;
}
blockquote,
q {
  quotes: none;
}
blockquote:before,
blockquote:after,
q:before,
q:after {
  content: "";
  content: none;
}
table {
  border-collapse: collapse;
  border-spacing: 0;
}

html,
body {
  background: #222;
}

h3 {
  color:#777;
  padding:4px;
  font-size:small;
  float: left;
  position: fixed;
}

img {
  width: 70px;
  height: 70px;
  margin: 20px;
  border-radius: 35px;
  background: #fff;
  border: 1px solid #fff;
}

a:hover img {
  width: 60px;
  height: 60px;
  margin: 25px;
  border-radius: 30px;
}

p {
  display: inline;
}

.header {
  background: #333;
  padding: 15px;
  text-align: right;
  color: #ddd;
}

.menu {
  text-align: left;
  float: left;
  width: 90%;
}

.menu a {
  color: #fff;
  text-decoration: none;
}

.menu a:hover {
  color: #aaa;
}

.menu .menu_seleted {
  display:none;
}

.bkmrks_item {
  display: inline;
  text-align: center;
}

.bkmrks_item_label {
  position: absolute;
  width: 112px;
  text-align: center;
  padding-top: 100px;
  color:#555;
  font-size: smaller;
}

a:hover .bkmrks_item_label{
  color:#AAA;
  font-weight: bold;
}

h2 { /* md generator use h2 for lonely elements*/
    display: block;
    border-bottom: 1px solid #FFF;
    padding-bottom: 0.5em;
}
