<!doctype html>
<html lang="en">
  <head>
    <title>Home</title>
    <style>/*{css}/**/</style>
  </head>
  <body>
    <div class="header">
      <div class="menu">
        {menu}
      </div>
      <span id="clock">00:00:00</span>
    </div>
    <div id="bkmrks_items">
      {html}
    </div>
  </body>
  <script>/*{js}/**/</script>
</html>
